#
# spec file for package kvazaar
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libkvazaar
%define libmver 3
Name:           kvazaar
Version:        1.1.0
Release:        3.1
Summary:        HEVC encoder
License:        LGPL-2.1
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://ultravideo.cs.tut.fi/#encoder
Source0:        https://github.com/ultravideo/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         kvazaar.memset.patch
BuildRequires:  automake
BuildRequires:  findutils
BuildRequires:  gcc >= 4.4
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
Requires:       %{libname}%{libmver} = %{version}
%ifnarch %{arm}
BuildRequires:  yasm
%endif

%description
An open-source HEVC encoder

%package -n %{libname}%{libmver}
Summary:        HEVC encoder
Group:          System/Libraries

%description -n %{libname}%{libmver}
%{libname} shared library

%package -n %{libname}-devel
Summary:        Header files %{libname}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{libmver} = %{version}

%description -n %{libname}-devel
Header files for the %{libname} library

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fvi
%configure \
    --disable-static \
    --disable-silent-rules
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{libname}%{libmver} -p /sbin/ldconfig
%postun -n %{libname}%{libmver} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir %{_datadir}/doc/%{name}
%doc %{_datadir}/doc/%{name}/COPYING
%doc %{_datadir}/doc/%{name}/CREDITS
%doc %{_datadir}/doc/%{name}/README.md
%{_bindir}/kvazaar
%{_mandir}/man1/kvazaar.1%{ext_man}

%files -n %{libname}%{libmver}
%defattr(-,root,root)
%doc COPYING CREDITS README.md
%{_libdir}/%{libname}.so.%{libmver}*

%files -n %{libname}-devel
%defattr(-,root,root)
%{_includedir}/kvazaar.h
%{_libdir}/%{libname}.so
%{_libdir}/pkgconfig/kvazaar.pc

%changelog
* Wed Feb 22 2017 scarabeus@opensuse.org
- Bit of spec cleanup
* Thu Feb 16 2017 aloisio@gmx.com
- Update to version 1.1.0
  * Both BDRate and speed improved slightly.
  Features:
  * Bitrate control now works at LCU level, giving more
    consistent results. (2318bd7)
  * Added --roi parameter for LCU level delta-QP control.
    (4a0121a)
  * Added --slices parameter for encapsulating tiles and
    WPP-rows into slice NAL's instead of using bitstream
    offsets. (1e6463c)
  * Temporal motion vector prediction now works with B-frames.
    (d892be5)
  Optimization:
  * Added AVX2 version of SSD. (778e46d)
  * Optimized intra reference building. (c31207e)
  * Optimized bitstream writes. (a9e45ef)
  * Optimized CU-split decision. (2c069a3)
  * Fix main-thread busy-looping on Linux. (a5a925f)
  * Avoid initializing memory needlessly during RDOQ.
    (acd12cb, b021d22)
  Fixes:
  * Pass DTS and PTS timestamps correctly through the API.
    (d18de19)
  * Fixed bug with subpixel motion estimation within tiles.
    (2c005cd)
  * Improved 10-bit RD-performance. (70a52f0)
  * Fixed for stupendously large bitstreams when
  - -mv-constraint was used with --subme. (937a764)
  * Fixed bug with --smp and --amp. (46c9a48)
  * Fix problem with --bipred. (1e6463c)
  * Fixed hang with threading on OSX. (d893474)
  * Fix crash when frame is less than 65 pixels high and WPP
    is used. (b8e3513)
  User Interface:
  * Disabled WPP with tiles enabled. (cb6672b)
  * Improved --help. (5bf7454, 78a28e0)
  * Made it possible to disable the gop-structure that was
    enabled by default in v.1.0.0. (deb63f7)
  * Have --threads=auto enable threading instead of disabling
    it. (db5e750)
  * Give errors on failures and handle them better. (97863cd,
    6a178de)
  * Use reference picture number of medium preset by default.
    (7ff33e1)
  Building:
  * Include optimizations on 32-bit. (1dcc993)
  * Added appveyor CI tests for MSYS2. (e269b86)
  * Add pkg-config macros, so pkg-config doesn't need to be
    installed anymore. (2d7daa1)
  * Travis CI OSX tests work again. (c32f5fa)
  Refactoring:
  * Refactored deblocking and sign hiding. (7ec5f78)
  * Removed Exp-Golomb lookup table. (ed3bd89)
  * Copy kvz_config to encoder_control_t and remove duplicate
    fields. (e78a8df)
* Tue Oct  4 2016 aloisio@gmx.com
- Update to version 1.0.0
  New Features
  * --version
  * --help
  * --loop-input
  * --mv-constraint to constrain motion vectors
  * --tiles=2x2 as an alternative syntax for uniform tiles
  * --hash=md5
  * Print information about what SIMD optimizations are in
    use
  * --mv=full8 --mv=full16 --mv=full32 --mv=full64
  * --cu-split-termination=zero/off
  * --crypto for selective encryption of bitstream (for
    OpenHEVC)
  * --me-early-termination=sensitive/on/off for early
    termination of motion vector search
  * Added 4x8 SMP and 4x12 AMP motion partitions
  * --subme=0/1/2/3/4 for control over complexity of
    fractional pixel motion prediction
  * --lossless for lossless coding
  * Monochrome coding
  * --input-format=420/400
  * --input-bitdepth=8/10
  * --tmpv for temporal motion vector predictor
  * --rdoq-skip for not using rdoq for situations where it's
    unlikely to improve BDRate
  * Modified --gop=lp-g4d3r1t1 syntax to not take the
    reference frames as a parameter, it's now --gop=lp-g4d3t1.
  * Enable WPP and multithreading by default, with detection
    for number of cores
  * Update all presets to ratedistortion-complexity
    optimized versions. These are based on a search of all
    (~ish) possible encoding parameters and bring a huge boost
    to both speed and BDRate when encoding with the presets (10x
    speed for veryslow, ~1.1x-4x for others, up to 30%% improved
    BDRate for some presets).
  * Set default options to match medium with intra period of
    64, QP 22 and --gop=lp-g4d3t1
  * --implicit-rdpcm RExt feature
  Optimizations
  * AVX2 version for Sample Adaptive Offset (SAO)
  * Optimized memory copying
  * AVX2 versions of filters for fractional pixel motion
    estimation
  * AVX2 version for half pixel chroma sampling for SMP/AMP
  * AVX2 versions for calculating two or four SATD values at
    once for small blocks
  * Rewrote AVX2 version of fractional pixel motion
    compensation
  * Rewrote motion vector cost calculation. It only got
    slightly faster, but BDRate improved a bunch due to the new
    implementation being more correct.
  * Made AVX2 SAD use SSE4.1 for cases where there isn't an
    AVX2 implementation, speeding up SMP/AMP.
  Bugfixes
  * Fixed a bug in rate control where an int overflowed
    after coding 2^31 bits (2Gb)
  * Fixed non-determinism intiles
  * Fixed chroma reconstruction bug in tiles
  * Fixed a bug with calculating the number of bits used for
    intra mode on 4x4 CUs
  * Stopped checking zero motion vector multiple times in
    motion compensation
  * Fixed possible segfault in motion compensation
  * Fixed a race condition with OWF and SMP/AMP
  * Gave pthread_cond_timedwait time in correctly, such that
    main thread now sleeps instead of busylooping when it has
    nothing to do
  * Fixed rate control with lp-gop
  * Fixed full search not taking temporal motion vector into
    account
  * Allow non-gop-length intra period for lp-gop
  Code / Building / Testing
  * Moved SAO to it's own file
  * Removed a ton of unnecessary includes
  * Updated autotools ax_pthread
  * Added build test for OS-X for Travis
  * Made tests check for bitstream correctness
  * Refactored some of the copypasta in motion vector search
    starting point selection
  * Refactored the cu_info_t datastructures to hold
    information at a 4x4 resolution needed for AMP and SMP
  * Changed cu_info_t to use bitfields to negate the effect
    of increasing the cu_info_t array by a factor of 4
  * Moved bitstream generation from encoderstate.c to
    encode_coding_tree.c
  * Renamed encoder_state_t.global to frame, which makes
    sense since it hold frame level data, not global data
  * Rewrote integer vector inter prediction, because it was
    so bad
  * Refactored init_lcu_t
  * Added more tests for inter SAD
  * Added speed tests for dual intra SAD functions
  * Added more realistic speed tests for inter SAD
  Other
  * Added a manpage
  * Added scripts for updating manpage and README based on
  - -usage.
  * Added a Dockerfile. Just because.
  * Added commit date to --version
* Thu Jan 28 2016 aloisio@gmx.com
- Update to version 0.8.3
* Sat Jan 16 2016 aloisio@gmx.com
- Update to version 0.8.2
- Bumped library version to 3
* Fri Jan 15 2016 aloisio@gmx.com
- Update to version 0.8.1
- Removed static library
* Mon Nov  2 2015 aloisio@gmx.com
- Update to version 0.7.2
* Sun Oct 25 2015 aloisio@gmx.com
- Update to version 0.7.1
  * bumped library version to 2
* Sat Oct 10 2015 aloisio@gmx.com
- Update to version 0.7.0
  * bumped library version to 1
- Removed kvazaar-arm.patch because it's now fixed upstream
* Fri Sep 18 2015 aloisio@gmx.com
- Update to version 0.6.1
* Tue Sep 15 2015 aloisio@gmx.com
- Initial version 0.6.0
